[![CircleCI](https://circleci.com/gh/lifespline/lifespline-utils/tree/dev.svg?style=svg)](https://circleci.com/gh/lifespline/lifespline-utils/tree/dev)
# Lifespline-Utils

Utils for the `lifespline` framework. Pip-install the package [here](https://pypi.org/project/lifespline-utils/).
